@@ -45,7 +45,6 @@ public:
 
     // helpers
     bool replaceStringInFile(const QString &oldtext, const QString &newtext, const QString &filepath);
-    void csleep(int msec);
 
     bool isInsideVB();
 
@@ -137,8 +136,13 @@ private slots:
     void on_localeCombo_currentIndexChanged(int index);
     void on_cmbTimeArea_currentIndexChanged(int index);
 
+    void on_radioOldHomeUse_toggled(bool);
+    void on_radioOldHomeSave_toggled(bool);
+    void on_radioOldHomeDelete_toggled(bool);
+
     void on_progressBar_valueChanged(int value);
 
+
 private:
     MProcess proc;
     int phase = 0;
@@ -199,9 +203,7 @@ private:
     bool canMBR, canPBR, canESP;
     bool haveSamba = false;
     bool haveSnapshotUserAccounts = false;
-    enum OldHomeAction {
-        OldHomeNothing, OldHomeUse, OldHomeSave, OldHomeDelete
-    } oldHomeAction = OldHomeNothing;
+    bool haveOldHome = false;
 
     // Advanced Encryption Settings page
     int ixPageRefAdvancedFDE = 0;
